@@ -352,9 +352,10 @@ generate_guide(int lineno)
 			strbuf_putc(sb, ' ');
 	strbuf_sprintf(sb, "%s/* ", comment_begin);
 	strbuf_puts(sb, link_format(anchor_getlinks(lineno)));
-	if (show_position)
-		strbuf_sprintf(sb, "%s%s[+%d %s]%s",
+	if (show_position) {
+		strbuf_sprintf(sb, "%s%s value='+%d %s' %s",
 			quote_space, position_begin, lineno, curpfile, position_end);
+	}
 	strbuf_sprintf(sb, " */%s", comment_end);
 
 	return strbuf_value(sb);
@@ -839,8 +840,10 @@ src2html(const char *src, const char *html, int notsource)
 		} else {
 			encode(sb, src);
 		}
+		strbuf_puts(sb, "?view=log");
 		if (cvsweb_cvsroot) {
-			strbuf_puts(sb, "?cvsroot=");
+			strbuf_puts(sb, quote_amp);
+			strbuf_puts(sb, "cvsroot=");
 			strbuf_puts(sb, cvsweb_cvsroot);
 		}
 		fputs(quote_space, out);
@@ -857,7 +860,7 @@ src2html(const char *src, const char *html, int notsource)
 
 	fputs(link_format(anchor_getlinks(0)), out);
 	if (show_position)
-		fprintf(out, "%s%s[+1 %s]%s", quote_space, position_begin, src, position_end);
+		fprintf(out, "%s%s value='+1 %s' %s", quote_space, position_begin, src, position_end);
 	fputs(" */", out);
 	fputs_nl(comment_end, out);
 	fputs_nl(hr, out);
@@ -996,7 +999,7 @@ src2html(const char *src, const char *html, int notsource)
 	fputs("/* ", out);
 	fputs(link_format(anchor_getlinks(-1)), out);
 	if (show_position)
-		fprintf(out, "%s%s[+%d %s]%s", quote_space, position_begin, last_lineno, src, position_end);
+		fprintf(out, "%s%s value='+%d %s' %s", quote_space, position_begin, last_lineno, src, position_end);
 	fputs(" */", out);
 	fputs_nl(comment_end, out);
 	if (insert_footer) {
