@@ -74,10 +74,7 @@ static int __bt_seqset(BTREE *, EPG *, DBT *, int);
  *	RET_ERROR, RET_SUCCESS or RET_SPECIAL if there's no next key.
  */
 int
-__bt_seq(dbp, key, data, flags)
-	const DB *dbp;
-	DBT *key, *data;
-	u_int flags;
+__bt_seq(const DB *dbp, DBT *key, DBT *data, u_int flags)
 {
 	BTREE *t;
 	EPG e;
@@ -147,11 +144,7 @@ __bt_seq(dbp, key, data, flags)
  *
  */
 static int
-__bt_seqset(t, ep, key, flags)
-	BTREE *t;
-	EPG *ep;
-	DBT *key;
-	int flags;
+__bt_seqset(BTREE *t, EPG *ep, DBT *key, int flags)
 {
 	PAGE *h;
 	pgno_t pg;
@@ -233,10 +226,7 @@ __bt_seqset(t, ep, key, flags)
  *	Pins the page the new key/data record is on.
  */
 static int
-__bt_seqadv(t, ep, flags)
-	BTREE *t;
-	EPG *ep;
-	int flags;
+__bt_seqadv(BTREE *t, EPG *ep, int flags)
 {
 	CURSOR *c;
 	PAGE *h;
@@ -334,11 +324,7 @@ usecurrent:		F_CLR(c, CURS_AFTER | CURS_BEFORE);
  *	or RET_SPECIAL if no such key exists.
  */
 static int
-__bt_first(t, key, erval, exactp)
-	BTREE *t;
-	const DBT *key;
-	EPG *erval;
-	int *exactp;
+__bt_first(BTREE *t, const DBT *key, EPG *erval, int *exactp)
 {
 	PAGE *h;
 	EPG *ep, save;
@@ -434,10 +420,7 @@ __bt_first(t, key, erval, exactp)
  *	@param index	page index
  */
 void
-__bt_setcur(t, pgno, index)
-	BTREE *t;
-	pgno_t pgno;
-	u_int index;
+__bt_setcur(BTREE *t, pgno_t pgno, u_int index)
 {
 	/* Lose any already deleted key. */
 	if (t->bt_cursor.key.data != NULL) {
