@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2006, 2013
+ * Copyright (c) 2006, 2013, 2014
  *	Tama Communications Corporation
  *
  * This file is part of GNU GLOBAL.
@@ -26,6 +26,7 @@
 #include <stdio.h>
 
 #include "gparam.h"
+#include "strbuf.h"
 
 #define FILEOP_INPUT	1
 #define FILEOP_OUTPUT	2
@@ -44,5 +45,6 @@ FILE *get_descripter(FILEOP *);
 void close_file(FILEOP *);
 void copyfile(const char *, const char *);
 void copydirectory(const char *, const char *);
+int read_first_line(const char *, STRBUF *);
 
 #endif /* ! _FILEOP_H */
