@@ -49,7 +49,7 @@ static int _mode;
 static int opened;
 static int created;
 
-int openflags;
+static int openflags;
 void
 set_gpath_flags(int flags) {
 	openflags = flags;
@@ -343,11 +343,11 @@ gpath_close(void)
 		dbop_close(dbop);
 		return;
 	}
-	if (_mode == 1 || _mode == 2) {
-		if (_startkey < _nextkey) {
-			snprintf(fid, sizeof(fid), "%d", _nextkey);
-			dbop_update(dbop, NEXTKEY, fid);
-		}
+	if (_mode == 1 ||
+           (_mode == 2 && _startkey < _nextkey))
+	{
+		snprintf(fid, sizeof(fid), "%d", _nextkey);
+		dbop_update(dbop, NEXTKEY, fid);
 	}
 	dbop_close(dbop);
 	if (_mode == 1)
