@@ -20,6 +20,6 @@
 #ifndef _STRLIMCPY_H_
 #define _STRLIMCPY_H_
 
-void strlimcpy(char *, const char *, const int);
+void strlimcpy(char *, const char *, int);
 
 #endif /* ! _STRLIMCPY_H_ */
