@@ -27,7 +27,7 @@ import optparse
 import pygments.lexers
 from pygments.token import Token
 
-EXUBERANT_CTAGS = "/usr/local/bin/ctags"
+UNIVERSAL_CTAGS = ""
 
 # In most cases, lexers can be looked up with lowercase form of formal
 # language names. This dictionary defines exceptions.
@@ -89,7 +89,7 @@ class PygmentsParser:
                     # we can assume index are delivered in ascending order
                     while self.lines_index[cur_line] <= index:
                         cur_line += 1
-                    tag = re.sub('\s+', '', tag)    # remove newline and spaces
+                    tag = re.sub(r'\s+', '', tag)    # remove newline and spaces
                     if self.options.strip_punctuation:
                         tag = tag.strip(PUNCTUATION_CHARACTERS)
                     if tag:
@@ -158,7 +158,7 @@ class CtagsParser:
             line = self.child_stdout.readline()
             if not line or line.startswith(TERMINATOR):
                 break
-            match = re.search(r'(\S+)\s+(\d+)\s+' + re.escape(path) + '\s+(.*)$', line)
+            match = re.search(r'(\S+)\s+(\d+)\s+' + re.escape(path) + r'\s+(.*)$', line)
             if match:
                 (tag, lnum, image) = match.groups()
                 if self.options.strip_punctuation:
@@ -200,14 +200,14 @@ def parse_langmap(string):
 
 def handle_requests(langmap, options):
     # Update ctags's path from the configuration file
-    global EXUBERANT_CTAGS
+    global UNIVERSAL_CTAGS
     path = load_ctags_path()
     if path != '':
-       EXUBERANT_CTAGS = path
-    if EXUBERANT_CTAGS != '' and EXUBERANT_CTAGS != 'no':
+       UNIVERSAL_CTAGS = path
+    if UNIVERSAL_CTAGS != '' and UNIVERSAL_CTAGS != 'no':
         pygments_parser = PygmentsParser(langmap, options)
         try:
-            ctags_parser = CtagsParser(EXUBERANT_CTAGS, options)
+            ctags_parser = CtagsParser(UNIVERSAL_CTAGS, options)
             parser = MergingParser(ctags_parser, pygments_parser)
         except Exception as e:
             parser = pygments_parser
@@ -244,7 +244,7 @@ def load_ctags_path():
         if sys.platform == 'win32' and sys.version_info >= (3,):
             path = io.TextIOWrapper(p.stdout, encoding='latin1').readline().rstrip()
         else:
-            path = p.stdout.readline().rstrip()
+            path = p.stdout.readline().rstrip().decode('latin1')
     return path
 
 def main():
